@@ -55,7 +55,7 @@ class BaseHandler(object):
         params = OrderedDict(sorted(params.items(), key=order_keys))
         
         # Add hash to dictionary if present
-        if hasattr(self, 'hash'):
+        if hasattr(self, 'hash') and self.hash is not None:
             params['hash'] = self.hash
         
         return params
@@ -65,6 +65,7 @@ class BaseHandler(object):
         Generates a hash based on the specific fields for the method.
         """
         
+        self.hash = None
         str_hash = ''
         
         for key, val in self._get_params().iteritems():
@@ -90,7 +91,8 @@ class BaseHandler(object):
             resp = self._endpoint(**params)
             logger.debug(resp)
         except WebFault, e:
-            logger.exception(e)
+            logger.exception('An error occurred while making the SOAP request.')
+            return None
         
         # Convert XML response into a dictionary
         self.response = XmlDictConfig(ElementTree.XML(smart_str(resp)))
